@@ -177,6 +177,10 @@ let get_stored_typed_expr ctx id =
 	let e = ctx.com.stored_typed_exprs#find id in
 	Texpr.duplicate_tvars (fun e -> get_this ctx e.epos) e
 
+let type_stored_expr ctx e1 =
+	let id = match e1 with (EConst (Int (s, _)),_) -> int_of_string s | _ -> die "" __LOC__ in
+	get_stored_typed_expr ctx id
+
 let assign_to_this_is_allowed ctx =
 	match ctx.curclass.cl_kind with
 		| KAbstractImpl _ ->
